@@ -97,7 +97,7 @@ void History::recordDeletions(const Akonadi::Item::List &items,
 {
     Entry::Ptr entry(new DeletionEntry(items, description, this));
 
-    foreach (const Akonadi::Item &item, items) {
+    for (const Akonadi::Item &item : items) {
         Q_UNUSED(item);
         Q_ASSERT_X(item.isValid(),
                    "History::recordDeletion()", "Item must be valid.");
@@ -222,7 +222,7 @@ void History::Private::handleFinished(IncidenceChanger::ResultCode changerResult
         stack().push(mEntryInProgress);
     }
 
-    mCurrentParent = Q_NULLPTR;
+    mCurrentParent = nullptr;
 
     // Process recordCreation/Modification/Deletions that came in while an operation
     // was in progress
