@@ -38,7 +38,7 @@
 #include <kcalutils/stringify.h>
 
 #include <identitymanager.h>
-#include <mailtransport/messagequeuejob.h>
+#include <mailtransportakonadi/messagequeuejob.h>
 #include <mailtransport/transportmanager.h>
 
 #include <KMessageBox>
@@ -87,7 +87,7 @@ ITIPHandlerDialogDelegate *ITIPHandlerComponentFactory::createITIPHanderDialogDe
 }
 
 ITIPHandler::ITIPHandler(QObject *parent) : QObject(parent)
-    , d(new Private(/*factory=*/Q_NULLPTR, this))
+    , d(new Private(/*factory=*/nullptr, this))
 {
     qRegisterMetaType<Akonadi::ITIPHandler::Result>("Akonadi::ITIPHandler::Result");
 }
@@ -142,7 +142,7 @@ void ITIPHandler::processiTIPMessage(const QString &receiver,
         qCritical() << "Error parsing" << errorMessage;
 
         if (d->m_showDialogsOnError) {
-            KMessageBox::detailedError(Q_NULLPTR, // mParent, TODO
+            KMessageBox::detailedError(nullptr, // mParent, TODO
                                        i18n("Error while processing an invitation or update."),
                                        errorMessage);
         }
@@ -171,7 +171,7 @@ void ITIPHandler::processiTIPMessage(const QString &receiver,
         // Find myself and set my status. This can't be done in the scheduler,
         // since this does not know the choice I made in the KMail bpf
         const KCalCore::Attendee::List attendees = d->m_incidence->attendees();
-        foreach (const KCalCore::Attendee::Ptr &attendee, attendees) {
+        for (const KCalCore::Attendee::Ptr &attendee : attendees) {
             if (attendee->email() == receiver) {
                 if (action.startsWith(QStringLiteral("accepted"))) {
                     attendee->setStatus(KCalCore::Attendee::Accepted);
@@ -207,8 +207,8 @@ void ITIPHandler::processiTIPMessage(const QString &receiver,
                                            << "; summary=" << d->m_incidence->summary();
 
             qCDebug(AKONADICALENDAR_LOG) << "\n Here's what we do have with such a summary:";
-            KCalCore::Incidence::List knownIncidences = calendar()->incidences();
-            foreach (const KCalCore::Incidence::Ptr &knownIncidence, knownIncidences) {
+            const KCalCore::Incidence::List knownIncidences = calendar()->incidences();
+            for (const KCalCore::Incidence::Ptr &knownIncidence : knownIncidences) {
                 if (knownIncidence->summary() == d->m_incidence->summary()) {
                     qCDebug(AKONADICALENDAR_LOG) << "\nFound: uid=" << knownIncidence->uid()
                                                  << "; identifier=" << knownIncidence->instanceIdentifier()
@@ -308,7 +308,7 @@ void ITIPHandler::sendiTIPMessage(KCalCore::iTIPMethod method,
     d->m_currentOperation = OperationSendiTIPMessage;
 
     KCalCore::Incidence *incidenceCopy = incidence->clone();
-    incidenceCopy->registerObserver(Q_NULLPTR);
+    incidenceCopy->registerObserver(nullptr);
     incidenceCopy->clearAttendees();
 
     d->m_scheduler->performTransaction(incidence, method);
